@@ -1,15 +1,19 @@
+from typing import TypeVar, Optional, Generic, Union
 import collections
 
 import discord
 from discord.ext import commands
 
 
+GuildT = TypeVar("GuildT", None, discord.Guild, Optional[discord.Guild])
+
+
 FakeResponse = collections.namedtuple("FakeResponse", ["status", "reason"])
 
 
 class AbstractMentionable(discord.Object):
     """
-    A fake mentionable object for use anywhere that you can't catch an error on a :code:`.mention` being None.
+    A fake mentionable object for use anywhere that you can't catch an error on a ``.mention`` being ``None``.
 
     Attributes:
         id (int): The ID of the mentionable.
@@ -21,8 +25,8 @@ class AbstractMentionable(discord.Object):
         """
         Args:
             id (int): The ID of the mentionable.
-            mention (str): The string to be returned when :code:`.mention` is run.
-            name (str): The string to be returned when :code:`.name` is run.
+            mention (str): The string to be returned when ``.mention`` is run.
+            name (str): The string to be returned when ``.name`` is run.
         """
 
         self.id = id
@@ -35,14 +39,9 @@ class AbstractMentionable(discord.Object):
 
 class ContextMixin:
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        try:
-            self.original_author_id = self.author.id
-        except AttributeError:
-            self.original_author_id = None
+    guild: Optional[discord.Guild]
 
-    def get_mentionable_channel(self, channel_id: int, fallback: str = "null") -> AbstractMentionable:
+    def get_mentionable_channel(self, channel_id: int, fallback: str = "null") -> Union[discord.TextChannel, AbstractMentionable]:
         """
         Get the mention string for a given channel ID.
 
@@ -51,17 +50,17 @@ class ContextMixin:
             fallback (str, optional): The string to fall back to if the channel isn't reachable.
 
         Returns:
-            typing.Union[discord.TextChannel, voxelbotutils.AbstractMentionable]: The mentionable channel.
+            Union[discord.TextChannel, voxelbotutils.AbstractMentionable]: The mentionable channel.
         """
 
         x = None
-        if channel_id is not None:
-            x = self.bot.get_channel(int(channel_id))
+        if channel_id is not None and self.guild:
+            x = self.guild.get_channel(int(channel_id))
         if x:
             return x
         return AbstractMentionable(channel_id, fallback, fallback)
 
-    def get_mentionable_role(self, role_id: int, fallback: str = "null") -> AbstractMentionable:
+    def get_mentionable_role(self, role_id: int, fallback: str = "null") -> Union[discord.Role, AbstractMentionable]:
         """
         Get the mention string for a given role ID.
 
@@ -70,18 +69,18 @@ class ContextMixin:
             fallback (str, optional): The string to fall back to if the role isn't reachable.
 
         Returns:
-            typing.Union[discord.Role, voxelbotutils.AbstractMentionable]: The mentionable role.
+            Union[discord.Role, voxelbotutils.AbstractMentionable]: The mentionable role.
         """
 
         x = None
-        if role_id is not None:
+        if role_id is not None and self.guild:
             x = self.guild.get_role(int(role_id))
         if x:
             return x
         return AbstractMentionable(role_id, fallback, fallback)
 
 
-class Context(commands.Context, ContextMixin):
+class Context(commands.Context, ContextMixin, Generic[GuildT]):
     """
     A modified version of the default :class:`discord.ext.commands.Context`.
 
@@ -90,6 +89,16 @@ class Context(commands.Context, ContextMixin):
             the bot's ``sudo`` command, if you want to check the original author.
     """
 
+    guild: GuildT
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.original_author_id: Optional[int]
+        try:
+            self.original_author_id = self.author.id
+        except AttributeError:
+            self.original_author_id = None
+
     async def okay(self) -> None:
         """
         Adds the okay hand reaction to a message.
@@ -98,7 +107,17 @@ class Context(commands.Context, ContextMixin):
         return await self.message.add_reaction("\N{OK HAND SIGN}")
 
 
-class SlashContext(commands.SlashContext, ContextMixin):
+class SlashContext(commands.SlashContext, ContextMixin, Generic[GuildT]):
+
+    guild: GuildT
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.original_author_id: Optional[int]
+        try:
+            self.original_author_id = self.author.id
+        except AttributeError:
+            self.original_author_id = None
 
     async def okay(self) -> None:
         """
@@ -117,7 +136,7 @@ class _NoRequestTyping(object):
         pass
 
 
-class _FakeStateMessage(object):
+class _FakeStateMessage(discord.Message):
 
     def __init__(self, state):
         self._state = state
@@ -126,9 +145,9 @@ class _FakeStateMessage(object):
 class PrintContext(Context):
 
     def __init__(self, bot):
-        self.message = _FakeStateMessage(bot._connection),
-        self.bot = bot,
-        self.prefix = ">>> ",
+        self.message = _FakeStateMessage(bot._connection)
+        self.bot = bot
+        self.prefix = ">>> "
 
     async def send(self, content, *args, **kwargs):
         print(content, args, kwargs)
